@@ -23,8 +23,8 @@
 
 static void         gail_combo_class_init              (GailComboClass *klass);
 static void         gail_combo_object_init             (GailCombo      *combo);
-static void         gail_combo_real_init               (GailWidget     *widget,
-                                                        GtkWidget      *gtk_widget);
+static void         gail_combo_real_initialize         (AtkObject      *obj,
+                                                        gpointer       data);
 
 static void         gail_combo_selection_changed_gtk   (GtkWidget      *widget,
                                                         gpointer       data);
@@ -117,18 +117,14 @@ gail_combo_class_init (GailComboClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   AtkObjectClass *class = ATK_OBJECT_CLASS (klass);
-  GailWidgetClass *widget_class;
-
-  widget_class = (GailWidgetClass*)klass;
 
   gobject_class->finalize = gail_combo_finalize;
 
-  parent_class = g_type_class_ref (GAIL_TYPE_CONTAINER);
-
-  widget_class->init = gail_combo_real_init;
+  parent_class = g_type_class_peek_parent (klass);
 
   class->get_n_children = gail_combo_get_n_children;
   class->ref_child = gail_combo_ref_child;
+  class->initialize = gail_combo_real_initialize;
 }
 
 static void
@@ -147,33 +143,32 @@ gail_combo_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_COMBO, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   accessible->role = ATK_ROLE_COMBO_BOX;
 
   return accessible;
 }
 
 static void
-gail_combo_real_init (GailWidget         *widget,
-                      GtkWidget          *gtk_widget)
+gail_combo_real_initialize (AtkObject *obj,
+                            gpointer  data)
 {
   GtkCombo *combo;
   GtkWidget *list, *entry;
-  AtkObject *obj, *child_accessible;
+  AtkObject *child_accessible;
 
-  GAIL_WIDGET_CLASS (parent_class)->init (widget, gtk_widget);
+  ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
 
-  combo = GTK_COMBO (gtk_widget);
+  combo = GTK_COMBO (data);
   list = combo->list;
   entry = combo->entry;
-  obj = ATK_OBJECT (widget);
 
   g_signal_connect (list,
                     "selection_changed",
                     G_CALLBACK (gail_combo_selection_changed_gtk),
-                    widget);
+                    obj);
   child_accessible = gtk_widget_get_accessible (entry);
   atk_object_set_parent (child_accessible, obj);
   child_accessible = gtk_widget_get_accessible (list);
