@@ -20,8 +20,8 @@
 #include <gtk/gtk.h>
 #include "gailtextcell.h"
 #include "gailcontainercell.h"
-#include "gailtexthelper.h"
 #include "gailcellparent.h"
+#include <util/gailmisc.h>
 
 static void      gail_text_cell_class_init		(GailTextCellClass *klass);
 static void      gail_text_cell_init			(GailTextCell	*text_cell);
@@ -76,6 +76,8 @@ static AtkAttributeSet* gail_text_cell_get_default_attributes
 
 static PangoLayout*     create_pango_layout             (GtkCellRendererText *gtk_renderer,
                                                          GtkWidget           *widget);
+static void             add_attr                        (PangoAttrList  *attr_list,
+                                                         PangoAttribute *attr);
 
 /* Misc */
 
@@ -165,7 +167,7 @@ gail_text_cell_class_init (GailTextCellClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GailRendererCellClass *renderer_cell_class = GAIL_RENDERER_CELL_CLASS (klass);
 
-  parent_class = g_type_class_ref (GAIL_TYPE_RENDERER_CELL);
+  parent_class = g_type_class_peek_parent (klass);
   renderer_cell_class->update_cache = gail_text_cell_update_cache;
   renderer_cell_class->property_list = gail_text_cell_property_list;
 
@@ -180,7 +182,7 @@ gail_text_cell_init (GailTextCell *text_cell)
   text_cell->cell_text = NULL;
   text_cell->caret_pos = 0;
   text_cell->cell_length = 0;
-  text_cell->texthelper = gail_text_helper_new ();
+  text_cell->textutil = gail_text_util_new ();
   atk_state_set_add_state (GAIL_CELL (text_cell)->state_set,
                            ATK_STATE_SINGLE_LINE);
 }
@@ -212,7 +214,7 @@ gail_text_cell_finalize (GObject            *object)
 {
   GailTextCell *text_cell = GAIL_TEXT_CELL (object);
 
-  g_object_unref (text_cell->texthelper);
+  g_object_unref (text_cell->textutil);
   g_free (text_cell->cell_text);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -262,8 +264,7 @@ gail_text_cell_update_cache (GailRendererCell *cell,
         }
     }
 
-  gail_text_helper_text_setup (text_cell->texthelper,
-                               text_cell->cell_text);
+  gail_text_util_text_setup (text_cell->textutil, text_cell->cell_text);
   
   if (rv)
     g_signal_emit_by_name (cell, "text_changed::insert",
@@ -296,7 +297,7 @@ gail_text_cell_get_text (AtkText *text,
                          gint    end_pos)
 {
   if (GAIL_TEXT_CELL (text)->cell_text)
-    return gail_text_helper_get_substring (GAIL_TEXT_CELL (text)->texthelper,
+    return gail_text_util_get_substring (GAIL_TEXT_CELL (text)->textutil,
               &start_pos, &end_pos);
   else
     return g_strdup ("");
@@ -309,7 +310,7 @@ gail_text_cell_get_text_before_offset (AtkText         *text,
                                        gint            *start_offset,
                                        gint            *end_offset)
 {
-  return gail_text_helper_get_text (GAIL_TEXT_CELL (text)->texthelper,
+  return gail_text_util_get_text (GAIL_TEXT_CELL (text)->textutil,
         NULL, GAIL_BEFORE_OFFSET, boundary_type, offset, start_offset,
         end_offset);
 }
@@ -321,7 +322,7 @@ gail_text_cell_get_text_at_offset (AtkText         *text,
                                    gint            *start_offset,
                                    gint            *end_offset)
 {
-  return gail_text_helper_get_text (GAIL_TEXT_CELL (text)->texthelper,
+  return gail_text_util_get_text (GAIL_TEXT_CELL (text)->textutil,
         NULL, GAIL_AT_OFFSET, boundary_type, offset, start_offset, end_offset);
 }
 
@@ -332,7 +333,7 @@ gail_text_cell_get_text_after_offset (AtkText         *text,
                                       gint            *start_offset,
                                       gint            *end_offset)
 {
-  return gail_text_helper_get_text (GAIL_TEXT_CELL (text)->texthelper,
+  return gail_text_util_get_text (GAIL_TEXT_CELL (text)->textutil,
         NULL, GAIL_AFTER_OFFSET, boundary_type, offset, start_offset,
         end_offset);
 }
@@ -401,7 +402,7 @@ gail_text_cell_get_run_attributes (AtkText *text,
   g_return_val_if_fail (GAIL_IS_CELL_PARENT (parent), NULL);
   widget = GTK_ACCESSIBLE (parent)->widget;
   layout = create_pango_layout (gtk_renderer, widget),
-  attrib_set = gail_text_helper_get_run_attributes (attrib_set, 
+  attrib_set = gail_misc_layout_get_run_attributes (attrib_set, 
                                                     layout,
                                                     gtk_renderer->text,
                                                     offset,
@@ -432,16 +433,16 @@ gail_text_cell_get_default_attributes (AtkText	*text)
   widget = GTK_ACCESSIBLE (parent)->widget;
   layout = create_pango_layout (gtk_renderer, widget),
 
-  attrib_set = gail_text_helper_add_attribute (attrib_set,
-                                               ATK_TEXT_ATTR_JUSTIFICATION,
-     g_strdup (atk_attribute_get_value (ATK_TEXT_ATTR_JUSTIFICATION, 0)));
-  attrib_set = gail_text_helper_add_attribute (attrib_set,
-                                               ATK_TEXT_ATTR_WRAP_MODE,
-              g_strdup (atk_attribute_get_value (ATK_TEXT_ATTR_WRAP_MODE, 0)));
+  attrib_set = gail_misc_add_attribute (attrib_set,
+                                        ATK_TEXT_ATTR_JUSTIFICATION,
+     g_strdup (atk_text_attribute_get_value (ATK_TEXT_ATTR_JUSTIFICATION, 0)));
+  attrib_set = gail_misc_add_attribute (attrib_set,
+                                        ATK_TEXT_ATTR_WRAP_MODE,
+              g_strdup (atk_text_attribute_get_value (ATK_TEXT_ATTR_WRAP_MODE, 0)));
 
-  attrib_set = gail_text_helper_get_default_attributes (attrib_set, 
-                                                        layout,
-                                                        widget);
+  attrib_set = gail_misc_get_default_attributes (attrib_set, 
+                                                 layout,
+                                                 widget);
   g_object_unref (G_OBJECT (layout));
   return attrib_set;
 }
@@ -461,17 +462,6 @@ create_pango_layout(GtkCellRendererText *gtk_renderer,
   PangoUnderline uline;
   PangoFontMask mask;
 
-  /* An internal convenience function to
-   * add a PangoAttribute to a PangoAttrList
-   */
-  void add_attr (PangoAttrList  *attr_list,
-                 PangoAttribute *attr)
-  {
-    attr->start_index = 0;
-    attr->end_index = G_MAXINT;
-    pango_attr_list_insert (attr_list, attr);
-  }
-  
   layout = gtk_widget_create_pango_layout (widget, gtk_renderer->text);
 
   if (gtk_renderer->extra_attrs)
@@ -535,6 +525,15 @@ create_pango_layout(GtkCellRendererText *gtk_renderer,
   return layout;
 }
 
+static void 
+add_attr (PangoAttrList  *attr_list,
+         PangoAttribute *attr)
+{
+  attr->start_index = 0;
+  attr->end_index = G_MAXINT;
+  pango_attr_list_insert (attr_list, attr);
+}
+
 static void      
 gail_text_cell_get_character_extents (AtkText          *text,
                                       gint             offset,
@@ -586,7 +585,7 @@ gail_text_cell_get_character_extents (AtkText          *text,
     offset) - gtk_renderer->text;
   pango_layout_index_to_pos (layout, index, &char_rect); 
 
-  gail_text_helper_get_extents_from_pango_rectangle (widget,
+  gail_misc_get_extents_from_pango_rectangle (widget,
       &char_rect, x_offset + rendered_rect.x,
       y_offset + rendered_rect.y, x, y, width, height, coords);
   g_object_unref (layout);
@@ -628,7 +627,7 @@ gail_text_cell_get_offset_at_point (AtkText          *text,
 
   layout = create_pango_layout (gtk_renderer, widget);
    
-  index = gail_text_helper_get_index_at_point_in_layout (widget, layout,
+  index = gail_misc_get_index_at_point_in_layout (widget, layout,
         x_offset + rendered_rect.x, y_offset + rendered_rect.y,
         x, y, coords);
   g_object_unref (layout);
